==> lxqt-session_0.17.1.orig.tar.xz: lxqt-session-0.17.1/lxqt-config-session/translations/lxqt-config-session_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>AutoStartEdit</name>
    <message>
        <location filename="../autostartedit.ui" line="14"/>
        <source>Edit</source>
        <translation>編集</translation>
    </message>
    <message>
        <location filename="../autostartedit.ui" line="20"/>
        <source>Name:</source>
        <translation>名称:</translation>
    </message>
    <message>
        <location filename="../autostartedit.ui" line="27"/>
        <source>Search...</source>
        <translation>検索...</translation>
    </message>
    <message>
        <location filename="../autostartedit.ui" line="47"/>
        <source>Command:</source>
        <translation>コマンド:</translation>
    </message>
    <message>
        <location filename="../autostartedit.ui" line="57"/>
        <source>Wait for system tray</source>
        <translation>システムトレイの起動を待つ</translation>
    </message>
    <message>
        <location filename="../autostartedit.cpp" line="61"/>
        <source>Select Application</source>
        <translation>アプリケーションの選択</translation>
    </message>
</context>
<context>
    <name>AutoStartItemModel</name>
    <message>
        <location filename="../autostartmodel.cpp" line="193"/>
        <source>Global Autostart</source>
        <translation>全体の自動起動</translation>
    </message>
    <message>
        <location filename="../autostartmodel.cpp" line="195"/>
        <source>LXQt Autostart</source>
        <translation>LXQt の自動起動</translation>
    </message>
    <message>
        <location filename="../autostartmodel.cpp" line="213"/>
        <source>Location: %1</source>
        <translation>場所: %1</translation>
    </message>
    <message>
        <location filename="../autostartmodel.cpp" line="215"/>
        <source>Overrides: %1</source>
        <translation>上書きにより無効: %1</translation>
    </message>
</context>
<context>
    <name>AutoStartPage</name>
    <message>
        <location filename="../autostartpage.ui" line="17"/>
        <source>Delete</source>
        <translation>削除</translation>
    </message>
    <message>
        <location filename="../autostartpage.ui" line="24"/>
        <source>Add</source>
        <translation>追加</translation>
    </message>
    <message>
        <location filename="../autostartpage.ui" line="31"/>
        <source>Edit</source>
        <translation>編集</translation>
    </message>
    <message>
        <location filename="../autostartpage.ui" line="44"/>
        <source>Application Autostart</source>
        <translation>アプリケーションの自動起動</translation>
    </message>
    <message>
        <location filename="../autostartpage.cpp" line="143"/>
        <source>Error</source>
        <translation>エラー</translation>
    </message>
    <message>
        <location filename="../autostartpage.cpp" line="143"/>
        <source>File &apos;%1&apos; already exists!</source>
        <translation>ファイル &apos;%1&apos; が既に存在しています！</translation>
    </message>
</context>
<context>
    <name>BasicSettings</name>
    <message>
        <location filename="../basicsettings.ui" line="23"/>
        <source>Basic Settings</source>
        <translation>基本設定</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="30"/>
        <source>Window Manager</source>
        <translation>ウィンドウマネージャー</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="49"/>
        <source>Search...</source>
        <translation>検索...</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="59"/>
        <source>LXQt Modules</source>
        <translation>LXQt モジュール</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="65"/>
        <source>Start</source>
        <translation>実行</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="72"/>
        <source>Stop</source>
        <translation>停止</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="111"/>
        <source>Leave Session</source>
        <translation>セッションの終了</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="117"/>
        <source>Ask for confirmation to leave session</source>
        <translation>セッション終了時に確認する</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="124"/>
        <source>Lock screen before suspending/hibernating</source>
        <translation>サスペンド/ハイバネートの前に画面をロックする　　　　　　</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="131"/>
        <source>Suspend/hibernate after lock delay:</source>
        <translation>ロックからサスペンド/ハイバネートまでの時間:</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="144"/>
        <source> ms</source>
        <translation> ミリ秒</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="156"/>
        <source>Select a window manager</source>
        <translation>ウィンドウマネージャーの選択</translation>
    </message>
</context>
<context>
    <name>EnvironmentPage</name>
    <message>
        <location filename="../environmentpage.ui" line="17"/>
        <source>Add</source>
        <translation>追加</translation>
    </message>
    <message>
        <location filename="../environmentpage.ui" line="24"/>
        <source>Delete</source>
        <translation>削除</translation>
    </message>
    <message>
        <location filename="../environmentpage.ui" line="50"/>
        <source>Environment Variables (Advanced)</source>
        <translation>環境変数(詳細)</translation>
    </message>
    <message>
        <location filename="../environmentpage.ui" line="61"/>
        <source>Variable Name</source>
        <translation>変数名</translation>
    </message>
    <message>
        <location filename="../environmentpage.ui" line="66"/>
        <source>Value</source>
        <translation>値</translation>
    </message>
</context>
<context>
    <name>ModuleModel</name>
    <message>
        <location filename="../modulemodel.cpp" line="87"/>
        <source>Running</source>
        <translation>実行中</translation>
    </message>
</context>
<context>
    <name>SessionConfigWindow</name>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="44"/>
        <source>LXQt Session Settings</source>
        <translation>LXQt セッションの設定</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="47"/>
        <source>Basic Settings</source>
        <translation>基本設定</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="53"/>
        <source>User Directories</source>
        <translation>ユーザーディレクトリ</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="59"/>
        <source>Autostart</source>
        <translation>自動起動</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="65"/>
        <source>Environment (Advanced)</source>
        <translation>環境(詳細)</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="87"/>
        <source>Session Restart Required</source>
        <translation>セッションの再起動が必要</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="88"/>
        <source>Some settings will not take effect until the next log in.</source>
        <translation>いくつかの設定項目は次のログインまで反映されません。</translation>
    </message>
</context>
<context>
    <name>UserLocationsPage</name>
    <message>
        <location filename="../userlocationspage.cpp" line="116"/>
        <source>Locations for Personal Files</source>
        <translation>個人ファイルの場所</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="185"/>
        <source>LXQt Session Settings - User Directories</source>
        <translation>LXQt セッションの設定 - ユーザーディレクトリ</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="186"/>
        <source>An error ocurred while applying the settings for the %1 location</source>
        <translation>%1 の場所の設定を適用している間にエラーが発生しました</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="202"/>
        <source>Choose Location</source>
        <translation>場所の選択</translation>
    </message>
</context>
<context>
    <name>UserLocationsPrivate</name>
    <message>
        <location filename="../userlocationspage.cpp" line="63"/>
        <source>Desktop</source>
        <translation>デスクトップ</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="64"/>
        <source>Downloads</source>
        <translation>ダウンロード</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="65"/>
        <source>Templates</source>
        <translation>テンプレート</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="66"/>
        <source>Public Share</source>
        <translation>共有</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="67"/>
        <source>Documents</source>
        <translation>ドキュメント</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="68"/>
        <source>Music</source>
        <translation>音楽</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="69"/>
        <source>Pictures</source>
        <translation>画像</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="70"/>
        <source>Videos</source>
        <translation>ビデオ</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="73"/>
        <source>Contains all the files which you see on your desktop</source>
        <translation>デスクトップ上で見れる全てのファイルを含みます</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="74"/>
        <source>Default folder to save your downloaded files</source>
        <translation>ダウンロードしたファイルを保存する既定のフォルダーです</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="75"/>
        <source>Default folder to load or save templates from or to</source>
        <translation>テンプレートファイルを保存する既定のフォルダーです</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="76"/>
        <source>Default folder to publicly share your files</source>
        <translation>共有ファイルを公開する既定のフォルダーです</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="77"/>
        <source>Default folder to load or save documents from or to</source>
        <translation>文書ファイルを保存する既定のフォルダーです</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="78"/>
        <source>Default folder to load or save music from or to</source>
        <translation>音楽ファイルを保存する既定のフォルダーです</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="79"/>
        <source>Default folder to load or save pictures from or to</source>
        <translation>画像ファイルを保存する既定のフォルダーです</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="80"/>
        <source>Default folder to load or save videos from or to</source>
        <translation>動画ファイルを保存する既定のフォルダーです</translation>
    </message>
</context>
</TS>

==> lxqt-session_1.1.1.orig.tar.xz: lxqt-session-1.1.1/lxqt-config-session/translations/lxqt-config-session_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>AutoStartEdit</name>
    <message>
        <location filename="../autostartedit.ui" line="14"/>
        <source>Edit</source>
        <translation>編集</translation>
    </message>
    <message>
        <location filename="../autostartedit.ui" line="20"/>
        <source>Name:</source>
        <translation>名称:</translation>
    </message>
    <message>
        <location filename="../autostartedit.ui" line="27"/>
        <source>Search...</source>
        <translation>検索...</translation>
    </message>
    <message>
        <location filename="../autostartedit.ui" line="47"/>
        <source>Command:</source>
        <translation>コマンド:</translation>
    </message>
    <message>
        <location filename="../autostartedit.ui" line="57"/>
        <source>Wait for system tray</source>
        <translation>システムトレイの起動を待つ</translation>
    </message>
    <message>
        <location filename="../autostartedit.cpp" line="61"/>
        <source>Select Application</source>
        <translation>アプリケーションの選択</translation>
    </message>
</context>
<context>
    <name>AutoStartItemModel</name>
    <message>
        <location filename="../autostartmodel.cpp" line="193"/>
        <source>Global Autostart</source>
        <translation>全体の自動起動</translation>
    </message>
    <message>
        <location filename="../autostartmodel.cpp" line="195"/>
        <source>LXQt Autostart</source>
        <translation>LXQt の自動起動</translation>
    </message>
    <message>
        <location filename="../autostartmodel.cpp" line="213"/>
        <source>Location: %1</source>
        <translation>場所: %1</translation>
    </message>
    <message>
        <location filename="../autostartmodel.cpp" line="215"/>
        <source>Overrides: %1</source>
        <translation>上書きにより無効: %1</translation>
    </message>
</context>
<context>
    <name>AutoStartPage</name>
    <message>
        <location filename="../autostartpage.ui" line="17"/>
        <source>Delete</source>
        <translation>削除</translation>
    </message>
    <message>
        <location filename="../autostartpage.ui" line="24"/>
        <source>Add</source>
        <translation>追加</translation>
    </message>
    <message>
        <location filename="../autostartpage.ui" line="31"/>
        <source>Edit</source>
        <translation>編集</translation>
    </message>
    <message>
        <location filename="../autostartpage.ui" line="44"/>
        <source>Application Autostart</source>
        <translation>アプリケーションの自動起動</translation>
    </message>
    <message>
        <location filename="../autostartpage.cpp" line="142"/>
        <source>Error</source>
        <translation>エラー</translation>
    </message>
    <message>
        <location filename="../autostartpage.cpp" line="142"/>
        <source>File &apos;%1&apos; already exists!</source>
        <translation>ファイル &apos;%1&apos; が既に存在しています！</translation>
    </message>
</context>
<context>
    <name>BasicSettings</name>
    <message>
        <location filename="../basicsettings.ui" line="23"/>
        <source>Basic Settings</source>
        <translation>基本設定</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="30"/>
        <source>Window Manager</source>
        <translation>ウィンドウマネージャー</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="49"/>
        <source>Search...</source>
        <translation>検索...</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="59"/>
        <source>LXQt Modules</source>
        <translation>LXQt モジュール</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="65"/>
        <source>Start</source>
        <translation>実行</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="72"/>
        <source>Stop</source>
        <translation>停止</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="111"/>
        <source>Global Screen Scaling</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="123"/>
        <source>Scale factor:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="149"/>
        <source>Leave Session</source>
        <translation>セッションの終了</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="155"/>
        <source>Ask for confirmation to leave session</source>
        <translation>セッション終了時に確認する</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="162"/>
        <source>Lock screen before suspending/hibernating</source>
        <translation>サスペンド/ハイバネートの前に画面をロックする&#x3000;&#x3000;&#x3000;&#x3000;&#x3000;&#x3000;</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="169"/>
        <source>Suspend/hibernate after lock delay:</source>
        <translation>ロックからサスペンド/ハイバネートまでの時間:</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="182"/>
        <source> ms</source>
        <translation> ミリ秒</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="176"/>
        <source>Select a window manager</source>
        <translation>ウィンドウマネージャーの選択</translation>
    </message>
</context>
<context>
    <name>EnvironmentPage</name>
    <message>
        <location filename="../environmentpage.ui" line="17"/>
        <source>Add</source>
        <translation>追加</translation>
    </message>
    <message>
        <location filename="../environmentpage.ui" line="24"/>
        <source>Delete</source>
        <translation>削除</translation>
    </message>
    <message>
        <location filename="../environmentpage.ui" line="50"/>
        <source>Environment Variables (Advanced)</source>
        <translation>環境変数(詳細)</translation>
    </message>
    <message>
        <location filename="../environmentpage.ui" line="61"/>
        <source>Variable Name</source>
        <translation>変数名</translation>
    </message>
    <message>
        <location filename="../environmentpage.ui" line="66"/>
        <source>Value</source>
        <translation>値</translation>
    </message>
</context>
<context>
    <name>ModuleModel</name>
    <message>
        <location filename="../modulemodel.cpp" line="87"/>
        <source>Running</source>
        <translation>実行中</translation>
    </message>
</context>
<context>
    <name>SessionConfigWindow</name>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="44"/>
        <source>LXQt Session Settings</source>
        <translation>LXQt セッションの設定</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="47"/>
        <source>Basic Settings</source>
        <translation>基本設定</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="53"/>
        <source>User Directories</source>
        <translation>ユーザーディレクトリ</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="59"/>
        <source>Autostart</source>
        <translation>自動起動</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="65"/>
        <source>Environment (Advanced)</source>
        <translation>環境(詳細)</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="91"/>
        <source>Session Restart Required</source>
        <translation>セッションの再起動が必要</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="92"/>
        <source>Some settings will not take effect until the next log in.</source>
        <translation>いくつかの設定項目は次のログインまで反映されません。</translation>
    </message>
</context>
<context>
    <name>UserLocationsPage</name>
    <message>
        <location filename="../userlocationspage.cpp" line="116"/>
        <source>Locations for Personal Files</source>
        <translation>個人ファイルの場所</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="184"/>
        <source>LXQt Session Settings - User Directories</source>
        <translation>LXQt セッションの設定 - ユーザーディレクトリ</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="185"/>
        <source>An error ocurred while applying the settings for the %1 location</source>
        <translation>%1 の場所の設定を適用している間にエラーが発生しました</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="201"/>
        <source>Choose Location</source>
        <translation>場所の選択</translation>
    </message>
</context>
<context>
    <name>UserLocationsPrivate</name>
    <message>
        <location filename="../userlocationspage.cpp" line="63"/>
        <source>Desktop</source>
        <translation>デスクトップ</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="64"/>
        <source>Downloads</source>
        <translation>ダウンロード</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="65"/>
        <source>Templates</source>
        <translation>テンプレート</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="66"/>
        <source>Public Share</source>
        <translation>共有</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="67"/>
        <source>Documents</source>
        <translation>ドキュメント</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="68"/>
        <source>Music</source>
        <translation>音楽</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="69"/>
        <source>Pictures</source>
        <translation>画像</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="70"/>
        <source>Videos</source>
        <translation>ビデオ</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="73"/>
        <source>Contains all the files which you see on your desktop</source>
        <translation>デスクトップ上で見れる全てのファイルを含みます</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="74"/>
        <source>Default folder to save your downloaded files</source>
        <translation>ダウンロードしたファイルを保存する既定のフォルダーです</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="75"/>
        <source>Default folder to load or save templates from or to</source>
        <translation>テンプレートファイルを保存する既定のフォルダーです</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="76"/>
        <source>Default folder to publicly share your files</source>
        <translation>共有ファイルを公開する既定のフォルダーです</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="77"/>
        <source>Default folder to load or save documents from or to</source>
        <translation>文書ファイルを保存する既定のフォルダーです</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="78"/>
        <source>Default folder to load or save music from or to</source>
        <translation>音楽ファイルを保存する既定のフォルダーです</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="79"/>
        <source>Default folder to load or save pictures from or to</source>
        <translation>画像ファイルを保存する既定のフォルダーです</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="80"/>
        <source>Default folder to load or save videos from or to</source>
        <translation>動画ファイルを保存する既定のフォルダーです</translation>
    </message>
</context>
</TS>
